<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>AboutDlg</name>
    <message>
        <location filename="aboutui.ui" line="14"/>
        <source>About GPSBabel</source>
        <translation>Acerca de GPSBabel</translation>
    </message>
    <message>
        <location filename="aboutui.ui" line="74"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;$babelfeversion$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Copyright (C) 2009 Robert Lipe&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;GUI designed and contributed by  S. Khai Mong&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;LGPL Crystal Icons by Alvarado Coehlo&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;(Using backend $babelversion$)&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;$upgradetestmode$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;This program is free software; you can redistribute it and/or  modify it under the terms of the GNU General Public License as  published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111 USA&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;$babelfeversion$&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright (C) 2009 S. Khai Mong&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;LGPL Crystal Icons by Alvarado Coehlo&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;(Using backend $babelversion$)&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Este programa es un programa libre, puedes distribuirlo o modificarlo de acuerdo a los términos de la licencia GNU tal y como la publica la Free Software Foundation, en su segunda versión o (si lo deseas) en cualquier versión posterior.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;El programa se distribuye confiando en su utilidad, pero sin ninguna garantía, incluso sin las garantías que conlleva la distribución de productos para un uso particular. Consulta la GNU General Public License si quieres más detalles.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Junto con el programa deberías haber recibido una copia de la  GNU General Public License, si es no fuera el caso, solícitala por escrito a la Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111 USA&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;$babelfeversion$&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright (C) 2009 S. Khai Mong&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;LGPL Crystal Icons by Alvarado Coehlo&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;(Using backend $babelversion$)&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This program is free software; you can redistribute it and/or  modify it under the terms of the GNU General Public License as  published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111 USA&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;$babelfeversion$&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright (C) 2009 S. Khai Mong&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;LGPL Crystal Icons by Alvarado Coehlo&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;(Using backend $babelversion$)&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Este progras es un programa libres, puedes distribuirlo o modificarlo de acuerdo a los términos de la licencia GNU tal y como la publica la Free Software Foundation, en su segunda versión o (si lo deseas) en cualquier versión posterior.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;El programa se distribuye confiando en su utilidad, pero sin ninguna garantía, incluso si la garantías que conlleva la distribución de productos para un uso particular. Consulta la GNU General Public License si quieres más detalles.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Junto con el programa deberías haber recibido una copia de la  GNU General Public License, si es no fuera el caso, solícitala por escrito a la Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111 USA&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>AdvUi</name>
    <message>
        <location filename="advui.ui" line="14"/>
        <source>Global Options</source>
        <translatorcomment>Opciones Generales</translatorcomment>
        <translation>Opciones Generales</translation>
    </message>
    <message>
        <location filename="advui.ui" line="23"/>
        <source>Synthesize short names</source>
        <translatorcomment>Crear nombres cortos</translatorcomment>
        <translation>Crear nombres cortos</translation>
    </message>
    <message>
        <source>Force Selected GPS data types (nuketypes filter)</source>
        <translatorcomment>Forzar el uso de los formatos GPS seleccionados (excluir tipos –rutas, tracks, puntos de interés– no deseados)</translatorcomment>
        <translation type="obsolete">Forzar el uso de los formatos GPS seleccionados (filtro nuketypes)</translation>
    </message>
    <message>
        <location filename="advui.ui" line="36"/>
        <source>Enable character set transformation</source>
        <translation>Permitir el cambio de codificación (caracteres)</translation>
    </message>
    <message>
        <location filename="advui.ui" line="43"/>
        <source>Preview in Google Maps</source>
        <translation>Ver en Google Maps</translation>
    </message>
    <message>
        <location filename="advui.ui" line="57"/>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <location filename="advui.ui" line="62"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="advui.ui" line="67"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="advui.ui" line="72"/>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <location filename="advui.ui" line="77"/>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <location filename="advui.ui" line="82"/>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <location filename="advui.ui" line="87"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="advui.ui" line="92"/>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <location filename="advui.ui" line="97"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="advui.ui" line="102"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="advui.ui" line="107"/>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <location filename="advui.ui" line="115"/>
        <source>Debugging Diagnostics</source>
        <translation>Depurar errores (debugging)</translation>
    </message>
    <message>
        <location filename="advui.ui" line="139"/>
        <source>Set all format input/output options to default values</source>
        <translation>Asignar a todas las opciones de entrada y salida los valores por defecto</translation>
    </message>
    <message>
        <location filename="advui.ui" line="142"/>
        <source>Default Format Options</source>
        <translation>Opciones de formato por defecto</translation>
    </message>
    <message>
        <location filename="advui.ui" line="33"/>
        <source>Convert character set encoding between input and output</source>
        <translation>Convertir la codificación de la entrada a la salida</translation>
    </message>
    <message>
        <location filename="advui.ui" line="52"/>
        <source>Debugging diagnostics.  
Higher number provides more deitaled diagnostics.</source>
        <translation>Depurar errores. Cuanto mayor es el número, el diagnóstico es más detallado.</translation>
    </message>
    <message>
        <location filename="advui.ui" line="20"/>
        <source>Create smart shortened names. </source>
        <translation>Crear nombres cortors de forma automática.</translation>
    </message>
</context>
<context>
    <name>Donate</name>
    <message>
        <location filename="donate.ui" line="32"/>
        <source>Support GPSBabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="47"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;GPSBabel is free software built and supported by volunteers. It consumes vast amounts of time to create and support the software as well as money for mapping programs, GPS receivers, and development fixtures. Please see how you can &lt;a href=&quot;http://www.gpsbabel.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;contribute time or via PayPal (no account needed) or Google Checkout.&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="61"/>
        <source>&lt;p&gt;Of course, if you&apos;ve already contributed  to the project or you just can&apos;t help the project, please check the box below to never see this message again.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="71"/>
        <source>Never show this message again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="93"/>
        <source>No, Thanks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="100"/>
        <source>Contribute</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileDlgManager</name>
    <message>
        <location filename="optionsdlg.cpp" line="70"/>
        <source>Select input file</source>
        <translation>Seleccionar archivo de entrada</translation>
    </message>
    <message>
        <location filename="optionsdlg.cpp" line="75"/>
        <source>Select output file</source>
        <translation>Seleccionar archivo de salida</translation>
    </message>
</context>
<context>
    <name>FilterDialog</name>
    <message>
        <location filename="filterdlg.cpp" line="41"/>
        <source>Tracks</source>
        <translation>Registro de trazados</translation>
    </message>
    <message>
        <location filename="filterdlg.cpp" line="44"/>
        <source>Waypoints</source>
        <translation>Puntos de interés</translation>
    </message>
    <message>
        <location filename="filterdlg.cpp" line="47"/>
        <source>Routes &amp; Tracks</source>
        <translation>Rutas y registro de trazados</translation>
    </message>
    <message>
        <location filename="filterdlg.cpp" line="50"/>
        <source>Miscellaneous</source>
        <translation>Miscelánea</translation>
    </message>
    <message>
        <location filename="filterdlg.cpp" line="104"/>
        <source>Are you sure you want to reset all filter options to default values?</source>
        <translation>¿Estás seguro de que quieres volver a las opciones por defecto de todos los filtros?</translation>
    </message>
</context>
<context>
    <name>FilterDlg</name>
    <message>
        <location filename="filterui.ui" line="14"/>
        <source>Data Filters</source>
        <translation>Filtros de datos</translation>
    </message>
    <message>
        <location filename="filterui.ui" line="17"/>
        <source>Data filters process and transform the data between input and output files or devices. </source>
        <translation>Procesar y transforma los datos entre los ficheros o aparatos de entrada y salida, de acuerdo a los filtros seleccionados. </translation>
    </message>
    <message>
        <location filename="filterui.ui" line="72"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="filterui.ui" line="83"/>
        <source>Reset</source>
        <translation>Volver al estado inicial</translation>
    </message>
</context>
<context>
    <name>GMapDialog</name>
    <message>
        <location filename="gmapdlg.cpp" line="55"/>
        <source>meters</source>
        <translation>metros</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="64"/>
        <source>feet</source>
        <translation>pies</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="68"/>
        <source>miles</source>
        <translation>millas</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="71"/>
        <source>Length: %1 %2
  %3 %4</source>
        <translation>Longitud:  %1 %2
  %3 %4</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="81"/>
        <source>Lat: %1</source>
        <translation>Lat: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="82"/>
        <source>Lng: %1</source>
        <translation>Lng: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="84"/>
        <source>Desc: %1</source>
        <translation>Desc: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="86"/>
        <source>Cmt: %1</source>
        <translatorcomment>Me falta contexto</translatorcomment>
        <translation>Cm:  %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="88"/>
        <source>Ele: %1</source>
        <translation>Ele: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="118"/>
        <source>Start: %1</source>
        <translation>Comenzar: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="120"/>
        <source>Stop: %1</source>
        <translation>Parar: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="123"/>
        <source>Points: %1</source>
        <translation>Puntos: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="149"/>
        <source>Waypoints</source>
        <translation>Puntos de interés</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="164"/>
        <source>Tracks</source>
        <translation>Registro de trazados</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="179"/>
        <source>Routes</source>
        <translation>Rutas</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="521"/>
        <source>Show All Waypoints</source>
        <translation>Mostrar todos los puntos de interés</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="522"/>
        <source>Hide All Waypoints</source>
        <translation>Ocultar todos los puntos de interés</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="523"/>
        <location filename="gmapdlg.cpp" line="531"/>
        <location filename="gmapdlg.cpp" line="539"/>
        <source>Expand All</source>
        <translation>Expandir todo</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="524"/>
        <location filename="gmapdlg.cpp" line="532"/>
        <location filename="gmapdlg.cpp" line="540"/>
        <source>Collapse All</source>
        <translation>Colapsar todo</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="529"/>
        <source>Show All Routes</source>
        <translation>Mostrar todas las rutas</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="530"/>
        <source>Hide All Routes</source>
        <translation>Ocultar todas las rutas</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="537"/>
        <source>Show All Tracks</source>
        <translation>Mostrar todos los trazados</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="538"/>
        <source>Hide All Tracks</source>
        <translation>Ocultar todos los trazados</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="545"/>
        <source>Show Only This Waypoint</source>
        <translation>Mostras sólo este punto de interés</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="551"/>
        <source>Show Only This Track</source>
        <translation>Mostrar sólo este trazado</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="557"/>
        <source>Show Only This Route</source>
        <translation>Mostrar sólo esta ruta</translation>
    </message>
</context>
<context>
    <name>GMapDlg</name>
    <message>
        <location filename="gmapui.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="gmapui.ui" line="47"/>
        <source>Copy to Clipboard</source>
        <translation>Copiar al portapapeles</translation>
    </message>
    <message>
        <location filename="gmapui.ui" line="50"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>About</source>
        <translation type="obsolete">Acerca de...</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="obsolete">Ayuda</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="obsolete">Archivo</translation>
    </message>
    <message>
        <source>Device</source>
        <translation type="obsolete">Dispositivo</translation>
    </message>
    <message>
        <source>Format</source>
        <translation type="obsolete">Formato</translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="obsolete">Opciones</translation>
    </message>
    <message>
        <source>Waypoints</source>
        <translation type="obsolete">Registros de trazado</translation>
    </message>
    <message>
        <source>Routes</source>
        <translation type="obsolete">Rutas</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation type="obsolete">Trazas</translation>
    </message>
    <message>
        <source>Output</source>
        <translation type="obsolete">Salida</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="263"/>
        <location filename="mainwindow.cpp" line="264"/>
        <source>default</source>
        <translation>Defecto</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="426"/>
        <source>Select one or more input files</source>
        <translation>Seleccionar uno o más archivos de entrada</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="453"/>
        <source>Output File Name</source>
        <translation>Nombre del fichero de salida</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="513"/>
        <source>Error reading format configuration.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH

This program cannot continue.</source>
        <translation>Se ha producido un error cuando se intentaba leer la configuración. Compruebe que el núcleo de &quot;gpsbabel&quot; está instalado correctamente y que se halla en la RUTA actual. Este programa no puede continuar.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="524"/>
        <source>Some file/device formats were not found during initialization.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH

This program cannot continue.</source>
        <translation>El formato de alfunos ficheros o dispositivos no se halló durante la inicialización. Compruebe que el núcleo de &quot;gpsbabel&quot; está instalado correctamente y que se halla en la RUTA actual. Este programa no puede continuar.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="546"/>
        <source>Input and output formats do not support %1</source>
        <translation>Formatos de entrada y salida inadmisibles %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="549"/>
        <source>Input does not support %1; output format supports %2</source>
        <translation>Formatos de entrada inadmisible %1; Formatos de salida inadmisible %2</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="552"/>
        <source>Input format supports %1; output format does not support %2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="555"/>
        <source>Both input and output formats support %1</source>
        <translation>Formatos de entrada y salida admisibles (ambos) %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="576"/>
        <source>waypoints</source>
        <translation>Puntos de interés</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="577"/>
        <source>tracks</source>
        <translation>Registro de trazados</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="578"/>
        <source>routes</source>
        <translation>Rutas</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="668"/>
        <source>There are no input options for format &quot;%1&quot;</source>
        <translation>No hay opciones de entrada para el formato &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="675"/>
        <location filename="mainwindow.cpp" line="695"/>
        <source>Options for %1</source>
        <translation>Opciones de %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="688"/>
        <source>There are no output options for format &quot;%1&quot;</source>
        <translation>No hay opciones de salida para el formato &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="709"/>
        <source>No valid waypoints/routes/tracks translation specified</source>
        <translation>Se han especificicado puntos de interés, trazados o rutas no traducibles</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="728"/>
        <source>No input file specified</source>
        <translation>No se ha especificado el fichero de entrada</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="735"/>
        <source>No valid output specified</source>
        <translation>El fichero de salida no es válido</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="740"/>
        <source>No output file specified</source>
        <translation>No se ha especificado el fichero de salida</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="756"/>
        <source>Process &quot;%1&quot; did not start</source>
        <translation>El proceso &quot;%1&quot; no comenzó</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="770"/>
        <source>Process exited unsucessfully with code %1</source>
        <translation>El proceso terminó sin suerte y con el código %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="913"/>
        <source>Translation successful</source>
        <translation>Traducción realizada con éxito</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="923"/>
        <source>Error running gpsbabel: %1
</source>
        <translation>Error ejecutando gpsbabel: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1036"/>
        <source>Are you sure you want to reset all format options to default values?</source>
        <translation>¿Estás seguro de que quieres volver a los formatos por defecto?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1060"/>
        <source>About %1</source>
        <translation>Acerca de %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1103"/>
        <source>One or more data filters are active</source>
        <translation>Uno o más filtros de datos están activos</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1105"/>
        <source>No data filters are active</source>
        <translation>Ningún filtro de datos está activo</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Ventana Principal</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="21"/>
        <source>Input </source>
        <translation>Entrada</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="41"/>
        <source>If selected, input is from a file.</source>
        <translation>Si se selecciona, la entrada esperada es un fichero.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="44"/>
        <location filename="mainwinui.ui" line="428"/>
        <location filename="mainwinui.ui" line="632"/>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="57"/>
        <source>If selected, input is from a device or GPS unit</source>
        <translation>Si se selecciona, la entrada esperada es un dispositivo o un GPS</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="60"/>
        <location filename="mainwinui.ui" line="444"/>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="89"/>
        <location filename="mainwinui.ui" line="473"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="96"/>
        <source>Input data format</source>
        <translation>Formato de entrada de datos</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="103"/>
        <source>Character encoding of input</source>
        <translation>Codificación de los caracteres de entrada</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="127"/>
        <source>Browse for one or more input files. </source>
        <translatorcomment>Podría ser más literal navega, pero buscar creo que se entiende mejor</translatorcomment>
        <translation>Busca uno o más ficheros de entrada. </translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="130"/>
        <source>File Name(s)</source>
        <translation>Nombre del o los ficheros</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="162"/>
        <location filename="mainwinui.ui" line="543"/>
        <source>Device Name:</source>
        <translation>Nombre del dispositivo:</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="169"/>
        <source>Name of port to which input device is connected</source>
        <translation>Nombre del puerto al que está conectado el dispositivo</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="200"/>
        <source>Options for the selected input format. </source>
        <translation>Opciones aplicables al formato de entrada seleccionado.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="203"/>
        <location filename="mainwinui.ui" line="584"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="218"/>
        <source>Translation Options</source>
        <translation>Opciones de conversión</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="227"/>
        <location filename="mainwinui.ui" line="270"/>
        <location filename="mainwinui.ui" line="310"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="237"/>
        <source>If selected, translate waypoints.</source>
        <translation>Si se selecciona, convertir puntos de interés.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="240"/>
        <source>Waypoints</source>
        <translation>Puntos de interés</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="277"/>
        <source>If selected, translate routes.</source>
        <translation>Si se selecciona, convertir las rutas.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="280"/>
        <source>Routes</source>
        <translation>Rutas</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="317"/>
        <source>If selected, translate tracks.</source>
        <translation>Si se selecciona, convertir los trazados.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="320"/>
        <source>Tracks</source>
        <translation>Trazados</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="356"/>
        <source>Data Filters between input and output</source>
        <translation>Filtros de datos entre la entrada y la salida</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="359"/>
        <source>Filters</source>
        <translation>Filtros</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="392"/>
        <source>More translation options. </source>
        <translation>Más opciones de conversión.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="395"/>
        <source>More Options</source>
        <translation>Más opciones</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="405"/>
        <source>Output</source>
        <translation>Salida</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="425"/>
        <source>If selected, output is to a file. </source>
        <translation>Si se selecciona, la salida es a un fichero. </translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="441"/>
        <source>If selected, output is to a device or GPS unit</source>
        <translation>Si se selecciona, la salida esperada es un dispositivo o un GPS</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="480"/>
        <source>Output data format.</source>
        <translation>Formato de salida de los datos.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="487"/>
        <source>Character encoding of output</source>
        <translation>Codificación de los caracteres de salida</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="508"/>
        <source>Browse for an output file name. </source>
        <translation>Selecciona el nombre del fichero de salida. </translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="511"/>
        <source>File Name</source>
        <translation>Nombre del fichero</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="550"/>
        <source>Name of port to which output device is connected</source>
        <translation>Nombre del puerto al que está conectado el dispositivo de salida</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="581"/>
        <source>Options for the selected output format. </source>
        <translation>Opciones aplicables al formato de salida seleccionado.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="605"/>
        <source>Output of GPSBabel translation process. </source>
        <translation>Salida del proceso de conversión de GPSBabel.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="639"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="655"/>
        <source>GPSBabel Help</source>
        <translation>Ayuda de GPSBabel</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="660"/>
        <source>About GPSBabel</source>
        <translation>Acerca de GPSBabel</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="665"/>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="670"/>
        <source>Preferences...</source>
        <translation>Preferencias ...</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="675"/>
        <source>Check for Upgrade</source>
        <translation>Comprueba si hay una actualización</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="680"/>
        <source>Visit Website...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="685"/>
        <source>Make a Donation...</source>
        <translation>Haga una donación...</translation>
    </message>
</context>
<context>
    <name>Map</name>
    <message>
        <location filename="map.cpp" line="66"/>
        <source>Missing &quot;gmapbase.html&quot; file.  Check installation</source>
        <translation>No se encuentra el fichero &quot;&quot;gmapbase.html&quot;. Compruebe la instalación</translation>
    </message>
    <message>
        <location filename="map.cpp" line="86"/>
        <source>Failed to load Google maps base page</source>
        <translation>Fallo al buscar la página básica de los mapas de Googe</translation>
    </message>
</context>
<context>
    <name>MiscFltWidget</name>
    <message>
        <location filename="miscfltui.ui" line="53"/>
        <location filename="filterwidgets.cpp" line="221"/>
        <location filename="filterwidgets.cpp" line="222"/>
        <location filename="filterwidgets.cpp" line="225"/>
        <location filename="filterwidgets.cpp" line="226"/>
        <source>Tracks</source>
        <translation>Trazados</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="60"/>
        <location filename="filterwidgets.cpp" line="221"/>
        <location filename="filterwidgets.cpp" line="223"/>
        <location filename="filterwidgets.cpp" line="224"/>
        <location filename="filterwidgets.cpp" line="226"/>
        <source>Waypoints</source>
        <translation>Puntos de interés</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="46"/>
        <location filename="filterwidgets.cpp" line="222"/>
        <location filename="filterwidgets.cpp" line="223"/>
        <location filename="filterwidgets.cpp" line="224"/>
        <location filename="filterwidgets.cpp" line="225"/>
        <source>Routes</source>
        <translation>Rutas</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="14"/>
        <source>Form</source>
        <translation>Formulario</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="27"/>
        <source>Misc. Filters</source>
        <translation>Otros filtros</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="34"/>
        <source>Nuke (Remove) Data Types</source>
        <translatorcomment>Espero que sea la traducción correcta (ADC)</translatorcomment>
        <translation>Borrar todo tipo de datos</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="72"/>
        <source>Convert routes, waypoints and tracks to different types.</source>
        <translation>Convertir rutas, puntos de interés y trazados a diferentes tipos.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="75"/>
        <source>This filter can be used to convert GPS data between different data types.

Some GPS data formats support only some subset of waypoints, tracks, and routes. The transform filter allows you to convert between these types. For example, it can be used to convert a pile of waypoints (such as those from a CSV file) into a track or vice versa. </source>
        <translation>Éste filtro puede ser utilizado para convertir datos GPS entre varios tipos de datos.

Algunos formatos de datos de los GPS solo permiten utilizar una parte de los puntos de interés, trazados o rutas. El filtro de transformación habilita la conversión entres esos tipos. Por ejemplo, se puede usar para convertir un conjunto de puntos de interés (como los contenidos en un fichero CSV) a un trazado o viceversa.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="80"/>
        <source>Transform</source>
        <translation>Transformar</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="87"/>
        <source>Type of transformation. </source>
        <translation>Tipos de transformación. </translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="94"/>
        <source>Delete original data after transform to prevent duplicated data. </source>
        <translation>Borrar los datos originales después de la transaformación para evitar la duplicación de los mismos.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="97"/>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="119"/>
        <source>Swap Longitude and Latitudes for badly formatted data formats.</source>
        <translation>Cambiar longitud y latitud en los formatos erróneos.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="122"/>
        <source>Simple filter to swap the coordinate values (latitude and longitude) of all points. This can be helpful for wrong defined/coded data. Or if you think, you can use one of our xcsv formats, but latitude and longitude are in opposite order. </source>
        <translation>Filtro simple para cambiar entre los valores de las coordenadas (latitud y longitud) de todos los puntos. Esto puede ser útil si los datos están mal definidos o si piensas que algún formato xcsv te puede ser útil pero la longitud y la latitud están en un orden incorrecto.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="125"/>
        <source>Swap Coordinates</source>
        <translation>Cambia longitud a latitud (y al revés)</translation>
    </message>
</context>
<context>
    <name>OptionsDlg</name>
    <message>
        <location filename="optionsdlg.cpp" line="189"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="preferences.ui" line="20"/>
        <source>GPSBabel Preferences</source>
        <translation>Preferencias de GPSBabel</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="30"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="45"/>
        <source>Check for newer version on start.</source>
        <translation>Comprobar actualizaciones al arrancar.</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="52"/>
        <source>Anonymously report usage data.</source>
        <translation>Enviar datos de uso de manera anónima.</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="59"/>
        <source>Ignore mismatch between command line and GUI version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="preferences.ui" line="68"/>
        <source>Formats</source>
        <translation>Formatos</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="76"/>
        <source>Enabled Formats</source>
        <translation>Formatos activos</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="100"/>
        <source>Enable All</source>
        <translation>Activar todo</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="107"/>
        <source>Disable All</source>
        <translation>Desactivar todo</translation>
    </message>
</context>
<context>
    <name>ProcessWaitDialog</name>
    <message>
        <location filename="processwait.cpp" line="43"/>
        <source>Process failed to start</source>
        <translation>El proceso no se inició</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="46"/>
        <source>Process crashed</source>
        <translation>El proceso falló</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="49"/>
        <source>Process timedout</source>
        <translation>Se ha excedido un tiempo razonable de espera sin que nada ocurra</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="52"/>
        <source>Error while trying to write to process</source>
        <translation>Error cuando se trataba de escribir al proceso</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="55"/>
        <source>Error while trying to read from process</source>
        <translation>Error cuando se trataba de leer desde el proceso</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="59"/>
        <source>Unknown process error</source>
        <translation>Error desconocido en el proceso</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="68"/>
        <source> ... Process GPSBabel</source>
        <translation>GPSBabel se está ejecutando ...</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="83"/>
        <source>Stop Process</source>
        <translation>Parar el proceso</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="154"/>
        <source>Process did not terminate successfully</source>
        <translation>El proceso no terminó como se esperaba</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="173"/>
        <source>Process crashed whle running</source>
        <translation>El proceso falló cuando estaba ejecutándose</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="formatload.cpp" line="155"/>
        <source>Error processing formats from running process &quot;gpsbabel -^3&quot; at line %1</source>
        <translation>Error al procesar los formatos seleccionados en el proceso &quot;gpsbabel -^3&quot; en la línea %1</translation>
    </message>
</context>
<context>
    <name>RtTrkWidget</name>
    <message>
        <location filename="rttrkui.ui" line="14"/>
        <source>Form</source>
        <translation>Formulario</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="17"/>
        <source>Simplify routes and tracks by removing points</source>
        <translation>Simplificar rutas y trazados, quitando algunos de sus puntos</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="20"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The Simplify filter is used to simplify routes and tracks for use with formats that limit the number of points they can contain or just to reduce the complexity of a route. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The filter attempts to remove points from each route until the number of points or the error is within the given bounds, while also attempting to preserve the shape of the original route as much as possible. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The quality of the results will vary depending on the density of points in the original route and the length of the original route. &lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;El filtro Simplificar se usa para hacer lo propio con rutas y trazados para que pueden utilizarse con formatos que limitan el número máximo de puntos que pueden contener, o simplemente para reducir la complejidad de una ruta (por eso se llama simplificar). &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;El filtro intenta quitar algunos puntos de cada rura hasta que el número de puntos o el margen de error se halla entre los límites dados, a la vez que intenta que la forma se parezca lo más posible a la ruta original.&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;La calidad de los resultados variará dependiendo del número de puntos que contenga la ruta original y de su longitud. &lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="40"/>
        <source>Routes &amp; Tracks</source>
        <translation>Rutas y registro de trazados</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="59"/>
        <source>Simplify</source>
        <translation>Simplificar</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="82"/>
        <source>Limit To</source>
        <translation>Limitar a </translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="89"/>
        <source>Maximum number points in track or route. </source>
        <translation>Máximo número de puntos en el trazado o en la ruta.</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="96"/>
        <source>Points</source>
        <translation>Puntos</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="118"/>
        <source>Reverse tracks and routes</source>
        <translation>Invertir rutas y trazados</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="125"/>
        <source>Reverse</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="49"/>
        <source>Simplify route by removing points</source>
        <translation>Simplificar la ruta quitando puntos</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="52"/>
        <source> The Simplify filter is used to simplify routes and tracks for use with formats that limit the number of points they can contain or just to reduce the complexity of a route.

The filter attempts to remove points from each route until the number of points or the error is within the given bounds, while also attempting to preserve the shape of the original route as much as possible.

The quality of the results will vary depending on the density of points in the original route and the length of the original route. </source>
        <translation> El filtro Simplificar se usa para hacer lo propio con rutas y trazados para que pueden utilizarse con formatos que limitan el número máximo de puntos que pueden contener, o simplemente para reducir la complejidad de una ruta (por eso se llama simplificar).

El filtro intenta quitar algunos puntos de cada ruta hasta que el número de puntos o el margen de error se halla entre los límites dados, a la vez que intenta que la forma se parezca lo más posible a la ruta original.

La calidad de los resultados variará dependiendo del número de puntos que contenga la ruta original y de su longitud. </translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="121"/>
        <source>The reversal is performed in the laziest way possible. Timestamps are kept with the original waypoints so the resulting track or route will have the interesting characteristic that time runs backwards. This tends to make Magellan Mapsend, in particular, do a wierd thing and place each waypoint on a separate day. 
Additionally, if you&apos;re using this to reverse a route that navigates, say, an exit ramp or a one way street, you will be in for unpleasant ride. application cares about timestamps </source>
        <translation>La inversión es realizada de la manera más simple posible. Los tiempos de marca de los puntos originales se guardan tal cual de tal forma que el trazado o la ruta resultantes tendrá características curiosas cuando el tiempo va para atrás. Esto hace que, sobre todo, Magellan Mapasend haga cosas raras como poner cada punto de interés en un día diferente. 
Además, si se utiliza este filtro para navegar por una ruta invertida que se mueve, por ejemplo una rampa de salida o una calle de sentido único, puedes encontrarte con un viaje poco apacible. Al programa le importan los tiempos de marca </translation>
    </message>
</context>
<context>
    <name>TrackWidget</name>
    <message>
        <location filename="trackui.ui" line="14"/>
        <source>Track Filter Options</source>
        <translation>Opciones de los filtros para los trazados</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="17"/>
        <source>This filter performs various operations on track data. </source>
        <translation>Este filtro efectúa varias operaciones en los registros de trazado.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="35"/>
        <source>Track Filters</source>
        <translation>Filtros para trazados</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="42"/>
        <source>Basic title for track</source>
        <translation>Título simple del trazado</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="45"/>
        <source>Basic title for new track(s). 
This option specifies a title for tracks generated by the track filter. By default, the title of the new track is composed of the start time of the track appended to this value. 
If this value contains a percent (%) character, it is treated as a format string for the POSIX strftime function, allowing custom time-based track names. </source>
        <translation>Título simple del trazado o trazados. Esta opción designa un título para los trazados generados por un filtro. Por defecto, el título del trazado resultante está formado por la fecha de comienzo del trazado añadida a su valor.
Si el título contiene un porcentaje (%) , es tratado como una cadena de texto por la función strftime POSIX lo que facilita el poner títulos que tienen en cuenta los datos temporales y los títulos de los trazados. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="50"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="57"/>
        <source>the title of the new track is composed of the start time of the track appended to this value. </source>
        <translation>el título del trazado resultante está formado por la fecha de comienzo del trazado añadida a su valor.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="64"/>
        <source>Correct track point timestamps by specified amount</source>
        <translation>Corregir el tiempo de los puntos de cada trazado en función de la cantidad añadida</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="67"/>
        <source>Correct trackpoint timestamps by a delta. 
This option changes the time of all trackpoints. This might be useful if your track must be moved by one or more hours because of an incorrect time zone. </source>
        <translation>Corregir el tiempo de los puntos de cada trazado con un incremento. Esta opción cambia los datos temporales de todos los puntos del trazado. Esto sería útil si tu trazado tuviera que ser trasladado una o más horas debido al cambio de huso horario. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="71"/>
        <source>Move</source>
        <translation>Mover</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="83"/>
        <location filename="trackui.ui" line="275"/>
        <source>days</source>
        <translation>días</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="97"/>
        <source>hours</source>
        <translation>horas</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="111"/>
        <location filename="trackui.ui" line="265"/>
        <source>mins</source>
        <translation>minutos</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="125"/>
        <source>secs</source>
        <translation>segundos</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="140"/>
        <location filename="trackui.ui" line="155"/>
        <source>Use track pts. after this time. </source>
        <translation>Usar sólo los puntos del trazado grabados después de esta hora.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="143"/>
        <source>Use only track points after this timestamp.

This option is used along with the stop to discard trackpoints that were recorded outside of a specific period of time. This option specifies the beginning of the time period. </source>
        <translation>Usar sólo los puntos del trazado grabados después de esta marca de tiempo.

Esta opción se utiliza junto con la de parar (stop) para descartar puntos que fueron grabados fuera del período de tiempo deseado. La opción especifica el inicio del período. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="148"/>
        <source>Start</source>
        <translation>Comenzar</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="162"/>
        <source>If checked, time specified here is based on this computer&apos;s current time zone. </source>
        <translation>Si seleccionado, los datos especificados se basan en la zona horaria de tu ordenador. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="165"/>
        <source>If checked, the times specified here are based on the local computer&apos;s time zone.  Otherwise it is UTC.</source>
        <translation>Si seleccionado, los datos especificados se basan en la zona horaria de tu ordenador. En caso contrario, es UTC.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="168"/>
        <source>Local Time</source>
        <translation>Hora local</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="181"/>
        <location filename="trackui.ui" line="196"/>
        <source>Use track pts before this time. </source>
        <translation>Usa los puntos del trazado tomados antes de esta hora. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="184"/>
        <source> Use only track points before this timestamp.

This option is used in conjunction with the start option to discard all trackpoints outside of a given period of time. This option defines the end of the time period. </source>
        <translation>Usa los puntos del trazado tomados antes de esta marca de tiempo. Esta opción se usa junto con la opción comenzar para descartar todos los puntos no tomados en determinado período temporal. Esta opción define el final del período. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="189"/>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="203"/>
        <source>Pack all tracks into one. </source>
        <translation>Junta todos los trazados en uno. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="206"/>
        <source>Pack all tracks into one.

This option causes all tracks to be appended to one another to form a single track. This option does not work if any two tracks overlap in time; in that case, consider using the merge option.

This option is most useful for rejoining tracks that might have been interrupted by an equipment malfunction or an overnight stop. </source>
        <translation>Junta todos los trazados en uno. 

Esta opción hace que todos los trazados se añadan uno tras otros hasta formar un único trazado. La opción no funciona si dos trazados se superponen temporalmente, en ese caso, puede ser mejor usar la opción unir.

Esta opción es muy útil para juntar trazados que se interrumpieron por un error en el equipo o por una parada para descansar. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="213"/>
        <source>Pack</source>
        <translation>Juntar</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="220"/>
        <source>Merge multiple tracks for the same way.</source>
        <translation>Unir diversos trazados repetitivos.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="223"/>
        <source> Merge multiple tracks for the same way.

This option puts all track points from all tracks into a single track and sorts them by time stamp. Points with identical time stamps will be dropped. </source>
        <translation>Unir diversos trazados repetitivos.

Esta opción pone todos los puntos de todos los trazados en un único trazado y los ordena por la marca de tiempo. Los puntos con idénticas marcas de tiempo son borrados.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="228"/>
        <source>Merge</source>
        <translation>Unir</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="235"/>
        <source>Split by Date</source>
        <oldsource>Split tracks. </oldsource>
        <translation>Dividir trazados por fecha</translation>
    </message>
    <message>
        <source>Split by date or time interval 

The input track will be split into several tracks depending on date of track points. If there is more than one track, use the pack option before before using this. 

If the input has multiple tracks, pack them together before splitting them back apart per day.
</source>
        <translation type="obsolete">Dividir por día o por intervalo horario 

El trazado de entrada será dividido en diversos trazados dependienco de la fecha de los puntos del trazado. Si hay más de un trzadado, utiliza antes la opción juntar.

Si la entrada tiene múltiples trazados, júntalos antes de dividirlos por día.</translation>
    </message>
    <message>
        <source>Split</source>
        <translation type="obsolete">Dividir</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="254"/>
        <source>If nonzero, the track will be split if the time between two points is greater than this parameter.   If zero, the track will be split by date. </source>
        <translation>Si &quot;nonzero&quot;, el trazado será dividido si el tiempo entre dos puntos es mayor que el parámetro.   Si &quot;zero&quot;, el trazado será dividido por día.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="270"/>
        <source>hrs</source>
        <translation>hrs</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="285"/>
        <source>Split by Dist.</source>
        <translation>Dividir trazados por distancia.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="297"/>
        <source>If nonzero, the input track will be split into several tracks if the distance between successive track points is greater than the distance given as a parameter. </source>
        <translation>Si &quot;nonzero&quot;, el trazado será dividido en varios trazados si la distancia entre dos puntos es mayor que el parámetro dado.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="308"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="313"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="318"/>
        <source>km</source>
        <translation>Km</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="323"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <source>Synthesize GPS Fixes. </source>
        <translatorcomment>No tengo claro lo que es esto </translatorcomment>
        <translation type="obsolete">Sintetizar las correcciones GPS. </translation>
    </message>
    <message>
        <source>Synthesize GPS fixes (PPS, DGPS, 3D, 2D, NONE).

This option sets the GPS fix status for all trackpoints to the specified value. Valid values for this option are PPS, DGPS, 3D, 2D, or NONE.

This option is most useful when converting from a format that doesn&apos;t contain GPS fix status to one that requires it. </source>
        <translation type="obsolete">Sintetizar las correcciones GPS (PPS, DGPS, 3D, 2D, NONE).

Esta opción fija el estatus de las correcciones GPS de todos los puntos del trazado al valor especificado. Los valores aceptables para esta opción son PPS, DGPS, 3D, 2D, o NONE.

Esta opción es muy útil cuando se trata de convertir de un formato que no contiene ninguna corrección GPS a uno que la requiere.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="341"/>
        <source>GPS Fixes</source>
        <translation>Correcciones GPS</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="349"/>
        <source>none</source>
        <translation>ninguno</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="354"/>
        <source>pps</source>
        <translation>pps</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="359"/>
        <source>dgps</source>
        <translation>dgps</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="364"/>
        <source>3d</source>
        <translation>3d</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="369"/>
        <source>2d</source>
        <translation>2d</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="407"/>
        <source>Synthesize course.</source>
        <translation>Sintetizar el rumbo.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="410"/>
        <source>Synthesize course.

This option computes (or recomputes) a value for the GPS heading at each trackpoint. This is most useful with trackpoints from formats that don&apos;t support heading information or for trackpoints synthesized by the interpolate filter. The heading at each trackpoint is simply the course from the previous trackpoint in the track. The first trackpoint in each track is arbitrarily assigned a heading of 0 degrees. </source>
        <translation>Sintetizar la dirección.

Esta opción calcula (o recalcula) un valor para el rumbo de cada punto del trazado. Es muy útil para puntos de trazado en formatos que no contienen información sobre el rumbo o para puntos de trazado calculados con el filtro interpolar. El rumbo de cada punto es simplemente la dirección desde el punto previo en el trazado. El primer punto de cada trazado tiene el valor arbitrario de 0 grados.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="415"/>
        <source>Course</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="392"/>
        <source>Synthesize speed. </source>
        <translation>Calcular velocidad. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="242"/>
        <source>Split by Time</source>
        <translation>Dividir trazados en función del tiempo</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="395"/>
        <source>Synthesize speed.

This option computes a value for the GPS speed at each trackpoint. This is most useful with trackpoints from formats that don&apos;t support speed information or for trackoints synthesized by the interpolate filter. The speed at each trackpoint is the average speed from the previous trackpoint (distance divided by time). The first trackpoint in each track is assigned a speed of &quot;unknown.&quot; </source>
        <translation>Sintetizar la veloclidad.

Esta opción calcula (o recalcula) un valor para la velocidad de cada punto del trazado. Es muy útil para puntos de trazado en formatos que no contienen información sobre la velocidad o para puntos de trazado calculados con el filtro interpolar. La velocidad de cada punto es simplemente la media (distancia partido por tiempo) desde el punto previo en el trazado. El primer punto de cada trazado tiene el valor arbitrario de &quot;desconocido&quot;.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="400"/>
        <source>Speed</source>
        <translation>Velocidad</translation>
    </message>
</context>
<context>
    <name>Upgrade</name>
    <message>
        <location filename="upgrade.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
</context>
<context>
    <name>UpgradeCheck</name>
    <message>
        <location filename="upgrade.cpp" line="207"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="upgrade.cpp" line="208"/>
        <source>Download failed: %1.</source>
        <translation>La descarga falló: %1.</translation>
    </message>
    <message>
        <location filename="upgrade.cpp" line="237"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="upgrade.cpp" line="238"/>
        <source>Invalid return data at line %1: %2.</source>
        <translation>Ha devuelto datos no válidos en la línea %1: %2.</translation>
    </message>
    <message>
        <location filename="upgrade.cpp" line="277"/>
        <source>A new version of GPSBabel is available.&lt;br /&gt;Your version is %1 &lt;br /&gt;The latest version is %2</source>
        <translation>Una nueva versióon de GPSBabel ha salido ya. &lt;br /&gt;Tu versión es la %1 &lt;br /&gt;La última versióon sería %2</translation>
    </message>
    <message>
        <location filename="upgrade.cpp" line="294"/>
        <source>Do you wish to download an upgrade?</source>
        <translation>¿Quieres bajarte una actualización?</translation>
    </message>
    <message>
        <source>&lt;center&gt;&lt;b&gt;A new version of GPSBabel is available&lt;/b&gt;&lt;br&gt;Your version is %1 &lt;br&gt;The latest version is %2&lt;/center&gt;</source>
        <translation type="obsolete">&lt;center&gt;&lt;b&gt;Una nueva versión de GPSBabel está disponible &lt;/b&gt;&lt;br&gt;La versión actual es %1 &lt;br&gt; La versión más reciente es %2&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="upgrade.cpp" line="288"/>
        <source>Upgrade</source>
        <translation>Actualizar</translation>
    </message>
</context>
<context>
    <name>VersionMismatch</name>
    <message>
        <location filename="version_mismatch.ui" line="32"/>
        <source>GPSBabel Version Mismatch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="38"/>
        <source>&lt;b&gt;A version mismatch has been detected.&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="47"/>
        <source>GPSBabel command line version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="81"/>
        <source>GPSBabel GUI version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="115"/>
        <source>Never show this message again.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WayPtsWidget</name>
    <message>
        <location filename="wayptsui.ui" line="14"/>
        <source>Form</source>
        <translation>Formulario</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="29"/>
        <source>Waypoints Filters</source>
        <translation>Filtros para puntos de interés</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="36"/>
        <source>Remove duplicates</source>
        <translation>Borrar duplicados</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="39"/>
        <source>The duplicate filter is designed to remove duplicate points based on their short name (traditionally a waypoint&apos;s name on the GPS receiver), and/or their location (to a precision of 6 decimals). This filter supports two options that specify how duplicates will be recognized, shortname and location. Generally, at least one of these options is required. </source>
        <translation>El filtro duplicados está designado para borrar los puntos duplicados basándose en el nombre corto (normalmente el nombre del punto de interés en el receptor GPS), y su localización (hasta una precisión de seis decimales). El filtro permite dos opciones para designar como serán tratados los duplicados, por nombre corto y localización. Normalmente, al menos una de esas opciones es requerida.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="42"/>
        <source>Duplicates</source>
        <translation>Duplicados</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="55"/>
        <source>Suppress duplicate waypoints based on name.</source>
        <translation>Suprimir duplicados con nombres idénticos.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="58"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Suppress duplicate waypoints based on name. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This option is the one most often used with the duplicate filter. This option instructs the duplicate filter to remove any waypoints that share a short name with a waypoint that has come before. This option might be used to remove duplicates if you are merging two datasets that were each created in part from a common ancestor dataset. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Suprimir duplicados con nombres idénticos. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Esta opción es una de la más usadas con el filtro de duplicados. La opción instruye al filtro para que borre los puntos que tienen el mismo nombre que uno ya procesado. La opcion puede usarse para borrar puntos cuando se unen dos conjuntos de datos que vienen de una fuente parcialmente común. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="66"/>
        <source>Short Names</source>
        <translation>Nombres cortos</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="73"/>
        <source>Suppress duplicate waypoint based on coords. </source>
        <translation>Suprimir los puntos de interés que comparten coordenadas. </translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="76"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Suppress duplicate waypoint based on coords. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This option causes the duplicate filter to remove any additional waypoint that has the same coordinates (to six decimal degrees) as a waypoint that came before. This option may be used to remove duplicate waypoints if the names are not expected to be the same. It also might be used along with the &lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;shortname&lt;/span&gt; option to remove duplicate waypoints if the names of several unrelated groups of waypoints might be the same. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Suprimir los puntos de interés que comparten coordenadas. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Esta opción es una de la más usadas con el filtro de duplicados. La opción instruye al filtro para que borre los puntos que tienen coordenadas idénticas a uno ya procesado. La opcion puede usarse para borrar puntos que se sabe no tienen el mismo nombre pero si la misma localización. &lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;nombre corto&lt;/span&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="84"/>
        <source>Locations</source>
        <translation>Lugares</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="91"/>
        <source>Remove points based on proximity</source>
        <translation>Borrar puntos próximos</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="94"/>
        <source>Maximum positional distance.

This option specifies the minimum allowable distance between two points. If two points are closer than this distance, only one of them is kept. </source>
        <translatorcomment>Hay una contradicción en el original</translatorcomment>
        <translation>Distancia máxima permitida.

Esta opción especifica la distancia máxima permitidad entre dos puntos. Si dos puntos están más alejados que la distancia dada un nuevo punto es creado.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="99"/>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="112"/>
        <source>Maximum positional distance.</source>
        <translation>Distancia máxima permitida.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="120"/>
        <source>Feet</source>
        <translation>Pies</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="125"/>
        <source>Meters</source>
        <translation>Metros</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="133"/>
        <source>Include points only within radius</source>
        <translation>Incluir sólo puntos dentro de un radio determinado</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="136"/>
        <source>This filter includes or excludes waypoints based on their proximity to a central point. All waypoints more than the specified distance from the specified point will be removed from the dataset.

By default, all remaining points are sorted so that points closer to the center appear earlier in the output file. </source>
        <translation>Este filtro incluye o excluye puntos de interés basándose en la proximidad a un punto central. Los puntos alejados más allá del radio proporcionado son excluidos del conjunto.

Por defecto, los puntos restantes se ordenan de acuerdo con su distancia al centro, el más cercano será el primero. </translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="141"/>
        <source>Radius</source>
        <translation>Radio</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="154"/>
        <source>Maximum distance from center. </source>
        <translation>Máxima distancia desde el centro.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="162"/>
        <source>Miles</source>
        <translation>Millas</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="167"/>
        <source>km</source>
        <translation>Km</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="175"/>
        <source>Lat.</source>
        <translation>Lat.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="188"/>
        <source>Latitude of the central point in decimal degrees.  South latitudes should be expressed as a negative number.</source>
        <translation>Latitud del punto central en grados decimales. Las latitudes Sur deben ser número negativos.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="195"/>
        <source>Long.</source>
        <translation>Long.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="208"/>
        <source>Longitude of the central point in decimal degrees. West longitudes should be expressed as a negative number.</source>
        <translation>Longitud del punto central en grados decimales. Las longitudes Oeste deben ser número negativos.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="215"/>
        <location filename="wayptsui.ui" line="218"/>
        <source>This filter sorts waypoints into alphabetical order</source>
        <translation>Este filtro ordena los puntos de interés en orden alfabético</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="221"/>
        <source>Sort</source>
        <translation>Ordenar</translation>
    </message>
</context>
</TS>
